---------------------------------------------------------------------------------
-- Re-create the SET_XACT_FRAUD_FL2 pro
---------------------------------------------------------------------------------
  
call sysproc.set_routine_opts('ISOLATION UR') @

drop specific procedure SET_XACT_FRAUD_FL2@

CREATE PROCEDURE SET_XACT_FRAUD_FLAG (
    IN I_TABNAME	CHARACTER(50),
    IN I_ALERT_TYPE CHARACTER(1),
    IN I_USER_NAME	CHARACTER(60),
    IN I_TRAN_IDS	VARCHAR(4000),
    IN I_FRAUD_IND	CHARACTER(1),
    IN I_NEED_TO_COMMIT	CHARACTER(1) )
  SPECIFIC SET_XACT_FRAUD_FL2
  LANGUAGE SQL
  NOT DETERMINISTIC
  EXTERNAL ACTION
  MODIFIES SQL DATA
  CALLED ON NULL INPUT
  INHERIT SPECIAL REGISTERS
-----------------------------------------------------------------------------
-- File:  SET_XACT_FRAUD_FLAG.SQL
--
--
-- Description:
--     Sets or unsets the cmx_user_fraud_ind column for a given account,
--     transaction_type, and array of transactions.
--
-- Called By:
--     SAVE_ALERT_AND_TRAN_IDS
--
-- Calls:
--     UPD_XACT_FRAUD_FLAG
--
-- Notes:
--     Originally stolen from specific procedure SET_XACT_FRAUD_FLA.
--
-- Usage:
--
--
-- History:
--     Date          User                Notes   
--     2008/03/07    leushe				 Added new parameter I_FRAUD_IND
--     						             created (stolen) from specific procedure UPD_XACT_FRAUD_FLA
--     2008/07/07    leushe              add the 2 new debit transaction tables FCM_DDAC, FCM_DANC to the valid tables list  
--     2010/01/14    leushe				 In V3.1, the UI sends in the trans_activity_acronym value from the fcm_grid_trans_activity table 
--                                       instead of the transaction acronym. Added a query to lookup the sor_table_name from the fcm_grid_trans_activity table.
--                                       This also eliminates the validation check, since fcm_grid_trans_activity.sor_table_name column
--                                       will always contain a vaild transaction table name
--
------------------------------------------------------------------------
P1: BEGIN

    DECLARE l_rowcount INTEGER DEFAULT 0;
    DECLARE l_index INTEGER DEFAULT 0;
    DECLARE l_iterator SMALLINT;
    DECLARE l_id CHAR(36);
    DECLARE l_pos INTEGER;
    DECLARE l_length INTEGER;
    DECLARE l_tabname CHAR(50);
    DECLARE l_stmtTemplate varchar(5000);
    DECLARE l_auditstmtTemplate varchar(5000);     
    
    DECLARE l_transaction_id_1 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_2 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_3 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_4 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_5 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_6 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_7 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_8 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_9 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_10 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_11 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_12 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_13 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_14 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_15 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_16 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_17 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_18 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_19 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_20 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_21 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_22 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_23 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_24 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_25 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_26 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_27 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_28 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_29 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_30 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_31 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_32 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_33 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_34 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_35 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_36 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_37 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_38 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_39 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_40 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_41 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_42 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_43 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_44 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_45 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_46 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_47 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_48 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_49 CHAR(36) DEFAULT NULL;
    DECLARE l_transaction_id_50 CHAR(36) DEFAULT NULL;

    DECLARE l_cmx_id_1 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_2 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_3 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_4 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_5 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_6 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_7 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_8 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_9 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_10 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_11 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_12 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_13 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_14 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_15 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_16 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_17 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_18 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_19 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_20 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_21 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_22 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_23 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_24 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_25 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_26 BIGINT DEFAULT 0;    
    DECLARE l_cmx_id_27 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_28 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_29 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_30 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_31 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_32 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_33 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_34 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_35 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_36 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_37 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_38 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_39 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_40 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_41 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_42 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_43 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_44 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_45 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_46 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_47 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_48 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_49 BIGINT DEFAULT 0;
    DECLARE l_cmx_id_50 BIGINT DEFAULT 0;

    
    -- Get the sor_table-name based on the trans_Activity_acronym passed in
    
	select sor_table_name into l_tabname 
	from fcm_grid_trans_activity
	where trans_activity_acronym = i_tabname;


    SET l_iterator = 1;
    SET l_length = length(rtrim(i_tran_ids))+1;
    SET l_pos = 1;

    WHILE (l_pos < l_length) DO

       SET l_index = sysfun.locate(',',i_tran_ids,l_pos);
       IF(l_index = 0) THEN
          SET l_id = substr(i_tran_ids,l_pos);
          SET l_pos = l_length;
       ELSE
          SET l_id = substr(i_tran_ids,l_pos,l_index-l_pos);
          SET l_pos = l_index+1;
       END IF;

       case l_iterator
          when 1 then set l_transaction_id_1 = l_id;
                      set l_cmx_id_1 = cast ( l_transaction_id_1 as bigint );
          when 2 then set l_transaction_id_2 = l_id;
                      set l_cmx_id_2 = cast ( l_transaction_id_2 as bigint );
          when 3 then set l_transaction_id_3 = l_id;
                      set l_cmx_id_3 = cast ( l_transaction_id_3 as bigint );
          when 4 then set l_transaction_id_4 = l_id;
                      set l_cmx_id_4 = cast ( l_transaction_id_4 as bigint );
          when 5 then set l_transaction_id_5 = l_id;
                      set l_cmx_id_5 = cast ( l_transaction_id_5 as bigint );
          when 6 then set l_transaction_id_6 = l_id;
                      set l_cmx_id_6 = cast ( l_transaction_id_6 as bigint );
          when 7 then set l_transaction_id_7 = l_id;
                      set l_cmx_id_7 = cast ( l_transaction_id_7 as bigint );
          when 8 then set l_transaction_id_8 = l_id;
                      set l_cmx_id_8 = cast ( l_transaction_id_8 as bigint );
          when 9 then set l_transaction_id_9 = l_id;
                      set l_cmx_id_9 = cast ( l_transaction_id_9 as bigint );
          when 10 then set l_transaction_id_10 = l_id;
                       set l_cmx_id_10 = cast ( l_transaction_id_10 as bigint );
          when 11 then set l_transaction_id_11 = l_id;
                       set l_cmx_id_11 = cast ( l_transaction_id_11 as bigint );
          when 12 then set l_transaction_id_12 = l_id;
                       set l_cmx_id_12 = cast ( l_transaction_id_12 as bigint );
          when 13 then set l_transaction_id_13 = l_id;
                       set l_cmx_id_13 = cast ( l_transaction_id_13 as bigint );
          when 14 then set l_transaction_id_14 = l_id;
                       set l_cmx_id_14 = cast ( l_transaction_id_14 as bigint );
          when 15 then set l_transaction_id_15 = l_id;
                       set l_cmx_id_15 = cast ( l_transaction_id_15 as bigint );
          when 16 then set l_transaction_id_16 = l_id;
                       set l_cmx_id_16 = cast ( l_transaction_id_16 as bigint );
          when 17 then set l_transaction_id_17 = l_id;
                       set l_cmx_id_17 = cast ( l_transaction_id_17 as bigint );
          when 18 then set l_transaction_id_18 = l_id;
                       set l_cmx_id_18 = cast ( l_transaction_id_18 as bigint );
          when 19 then set l_transaction_id_19 = l_id;
                       set l_cmx_id_19 = cast ( l_transaction_id_19 as bigint );
          when 20 then set l_transaction_id_20 = l_id;
                       set l_cmx_id_20 = cast ( l_transaction_id_20 as bigint );
          when 21 then set l_transaction_id_21 = l_id;
                       set l_cmx_id_21 = cast ( l_transaction_id_21 as bigint );
          when 22 then set l_transaction_id_22 = l_id;
                       set l_cmx_id_22 = cast ( l_transaction_id_22 as bigint );
          when 23 then set l_transaction_id_23 = l_id;
                       set l_cmx_id_23 = cast ( l_transaction_id_23 as bigint );
          when 24 then set l_transaction_id_24 = l_id;
                       set l_cmx_id_24 = cast ( l_transaction_id_24 as bigint );
          when 25 then set l_transaction_id_25 = l_id;
                       set l_cmx_id_25 = cast ( l_transaction_id_25 as bigint );
          when 26 then set l_transaction_id_26 = l_id;
                       set l_cmx_id_26 = cast ( l_transaction_id_26 as bigint );
          when 27 then set l_transaction_id_27 = l_id;
                       set l_cmx_id_27 = cast ( l_transaction_id_27 as bigint );
          when 28 then set l_transaction_id_28 = l_id;
                       set l_cmx_id_28 = cast ( l_transaction_id_28 as bigint );
          when 29 then set l_transaction_id_29 = l_id;
                       set l_cmx_id_29 = cast ( l_transaction_id_29 as bigint );
          when 30 then set l_transaction_id_30 = l_id;
                       set l_cmx_id_30 = cast ( l_transaction_id_30 as bigint );
          when 31 then set l_transaction_id_31 = l_id;
                       set l_cmx_id_31 = cast ( l_transaction_id_31 as bigint );
          when 32 then set l_transaction_id_32 = l_id;
                       set l_cmx_id_32 = cast ( l_transaction_id_32 as bigint );
          when 33 then set l_transaction_id_33 = l_id;
                       set l_cmx_id_33 = cast ( l_transaction_id_33 as bigint );
          when 34 then set l_transaction_id_34 = l_id;
                       set l_cmx_id_34 = cast ( l_transaction_id_34 as bigint );
          when 35 then set l_transaction_id_35 = l_id;
                       set l_cmx_id_35 = cast ( l_transaction_id_35 as bigint );
          when 36 then set l_transaction_id_36 = l_id;
                       set l_cmx_id_36 = cast ( l_transaction_id_36 as bigint );
          when 37 then set l_transaction_id_37 = l_id;
                       set l_cmx_id_37 = cast ( l_transaction_id_37 as bigint );
          when 38 then set l_transaction_id_38 = l_id;
                       set l_cmx_id_38 = cast ( l_transaction_id_38 as bigint );
          when 39 then set l_transaction_id_39 = l_id;
                       set l_cmx_id_39 = cast ( l_transaction_id_39 as bigint );
          when 40 then set l_transaction_id_40 = l_id;
                       set l_cmx_id_40 = cast ( l_transaction_id_40 as bigint );
          when 41 then set l_transaction_id_41 = l_id;
                       set l_cmx_id_41 = cast ( l_transaction_id_41 as bigint );
          when 42 then set l_transaction_id_42 = l_id;
                       set l_cmx_id_42 = cast ( l_transaction_id_42 as bigint );
          when 43 then set l_transaction_id_43 = l_id;
                       set l_cmx_id_43 = cast ( l_transaction_id_43 as bigint );
          when 44 then set l_transaction_id_44 = l_id;
                       set l_cmx_id_44 = cast ( l_transaction_id_44 as bigint );
          when 45 then set l_transaction_id_45 = l_id;
                       set l_cmx_id_45 = cast ( l_transaction_id_45 as bigint );
          when 46 then set l_transaction_id_46 = l_id;
                       set l_cmx_id_46 = cast ( l_transaction_id_46 as bigint );
          when 47 then set l_transaction_id_47 = l_id;
                       set l_cmx_id_47 = cast ( l_transaction_id_47 as bigint );
          when 48 then set l_transaction_id_48 = l_id;
                       set l_cmx_id_48 = cast ( l_transaction_id_48 as bigint );
          when 49 then set l_transaction_id_49 = l_id;
                       set l_cmx_id_49 = cast ( l_transaction_id_49 as bigint );
          when 50 then set l_transaction_id_50 = l_id;
                       set l_cmx_id_50 = cast ( l_transaction_id_50 as bigint );
       end case;

      SET l_iterator = l_iterator + 1;
    END WHILE;

  
       call upd_xact_fraud_flag
               (l_tabname, I_ALERT_TYPE, i_user_name, i_fraud_ind,l_iterator-1,
                l_cmx_id_1, l_cmx_id_2, l_cmx_id_3,
                l_cmx_id_4, l_cmx_id_5, l_cmx_id_6,
                l_cmx_id_7, l_cmx_id_8, l_cmx_id_9,
                l_cmx_id_10, l_cmx_id_11, l_cmx_id_12,
                l_cmx_id_13, l_cmx_id_14, l_cmx_id_15,
                l_cmx_id_16, l_cmx_id_17, l_cmx_id_18,
                l_cmx_id_19, l_cmx_id_20, l_cmx_id_21,
                l_cmx_id_22, l_cmx_id_23, l_cmx_id_24,
                l_cmx_id_25, 
                l_cmx_id_26, l_cmx_id_27, l_cmx_id_28,
                l_cmx_id_29, l_cmx_id_30, l_cmx_id_31,
                l_cmx_id_32, l_cmx_id_33, l_cmx_id_34,
                l_cmx_id_35, l_cmx_id_36, l_cmx_id_37,
                l_cmx_id_38, l_cmx_id_39, l_cmx_id_40,
                l_cmx_id_41, l_cmx_id_42, l_cmx_id_43,
                l_cmx_id_44, l_cmx_id_45, l_cmx_id_46,
                l_cmx_id_47, l_cmx_id_48, l_cmx_id_49,
                l_cmx_id_50, 
                i_need_to_commit);






    --
    -- The commit/rollback decision has to be handled by the caller.
    --


   IF (i_need_to_commit = 'Y') THEN
      commit;
   END IF;


  END P1@



